# Sample Deployment and Usage

 **These setups are not meant to be for production usage**.

Manage relay service with [Docker Compose](../deployments/compose/README.md).

Manage relay service on [Google Cloud Kubernetes Engine](../deployments/gke/README.md)

Manage relay service on [AWS Cloud](../deployments/aws/README.md)
